@@ -1,6 +1,6 @@
 package Test::Excel;
 
-$Test::Excel::VERSION   = '1.37';
+$Test::Excel::VERSION   = '1.38';
 $Test::Excel::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Test::Excel - Interface to test and compare Excel files.
 
 =head1 VERSION
 
-Version 1.37
+Version 1.38
 
 =cut
 
@@ -596,7 +596,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Test-Excel>
+L<https://github.com/manwar/Test-Excel>
 
 =head1 BUGS
 
@@ -635,7 +635,7 @@ L<http://search.cpan.org/dist/Test-Excel/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2010 - 2015 Mohammad S Anwar.
+Copyright (C) 2010 - 2016 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it  and/or modify it under
 the  terms  of the the Artistic License (2.0). You may  obtain a copy of the full
